<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Starta om Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Lock Screen</source>
        <translation>Lås skärm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Log Out</source>
        <translation>Logga ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Suspend</source>
        <translation>Vänteläge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Reboot</source>
        <translation>Starta om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="27"/>
        <source>Shutdown</source>
        <translation>Stäng av</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Pop-up med avslutningsalternativ för MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>Visa knappar i ett vertikalt fönster</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Visa knappar i ett horisontellt fönster</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>Timeout varaktighet i sekunder</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>använd -v, --vertical för att visa knappar vertikalt
använd -h, --horizontal för att visa knappar horisontellt.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Användning: exit-options [options]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>Alternativ:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Alternativ för att visa knappar horisontellt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Alternativ för att visa knappar vertikalt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 Timeout varaktighet i sekunder
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Den skärmorientering som används blir ihågkommen och används nästa gång du startar appen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativt, ställ in alternativet &apos;layout=horizontal&apos; eller &apos;layout=vertical&apos; i ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>För att ställa in timeout i exit-options.conf använd &apos;timeout=X&apos; där X är timeout i sekunder.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Du kan definiera anpassade ikoner genom att lägga till IconName=/path/iconame.ext i exit-options.conf filen. Namnen på ikonerna du ändrar: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Andra alternativ kan ställas in i exit-options.conf filen: %1</translation>
    </message>
</context>
</TS>
